from fastapi import APIRouter
from pydantic import BaseModel

from .entities import Entity, EntityList

import spacy

router = APIRouter()


class Data(BaseModel):
    document: str


@router.post("/named-entity-recognizer", response_model=EntityList)
def named_entity_recognition(data: Data, model: str = 'en_core_web_sm'):
    data = data.dict()
    doc = data.get('document')
    nlp = spacy.load(model)
    doc = nlp(doc)

    entities = [{'text': ent.text, 'label': ent.label_,
                 'start': ent.start_char, 'end': ent.end_char}
                for ent in doc.ents]

    return {"entities": entities}
